@@ -33,6 +33,7 @@ module Ast_407 = Ast_407
 module Ast_408 = Ast_408
 module Ast_409 = Ast_409
 module Ast_410 = Ast_410
+module Ast_411 = Ast_411
 (*$*)
 
 (* A module for marshalling/unmarshalling arbitrary versions of Asts *)
@@ -59,6 +60,8 @@ module Migrate_408_409 = Migrate_parsetree_408_409
 module Migrate_409_408 = Migrate_parsetree_409_408
 module Migrate_409_410 = Migrate_parsetree_409_410
 module Migrate_410_409 = Migrate_parsetree_410_409
+module Migrate_410_411 = Migrate_parsetree_410_411
+module Migrate_411_410 = Migrate_parsetree_411_410
 (*$*)
 
 (* An abstraction of OCaml compiler versions *)
@@ -79,6 +82,7 @@ module OCaml_407 = Versions.OCaml_407
 module OCaml_408 = Versions.OCaml_408
 module OCaml_409 = Versions.OCaml_409
 module OCaml_410 = Versions.OCaml_410
+module OCaml_411 = Versions.OCaml_411
 (*$*)
 module OCaml_current = Versions.OCaml_current
 
